@@ -58,11 +58,11 @@ void Dolphin::openNewWindow(const QList<QUrl> &urls, QWidget *window, const Open
     job->start();
 }
 
-bool Dolphin::attachToExistingInstance(const QList<QUrl>& inputUrls, bool openFiles, bool splitView, const QString& preferredService)
+bool Dolphin::attachToExistingInstance(const QList<QUrl>& inputUrls, bool openFiles, bool splitView, const QString& preferredService, const QString &activationToken)
 {
     bool attached = false;
 
-    if (inputUrls.isEmpty() || !GeneralSettings::openExternallyCalledFolderInNewTab()) {
+    if (inputUrls.isEmpty()) {
         return false;
     }
 
@@ -71,35 +71,70 @@ bool Dolphin::attachToExistingInstance(const QList<QUrl>& inputUrls, bool openFi
         return false;
     }
 
-    QStringList newUrls;
+    int activeWindowIndex = -1;
+    for (const auto& interface: qAsConst(dolphinInterfaces)) {
+        ++activeWindowIndex;
 
-    // check to see if any instances already have any of the given URLs open
-    const auto urls = QUrl::toStringList(inputUrls);
-    for (const QString& url : urls) {
+        auto isActiveWindowReply = interface.first->isActiveWindow();
+        isActiveWindowReply.waitForFinished();
+        if (!isActiveWindowReply.isError() && isActiveWindowReply.value()) {
+            break;
+        }
+    }
+
+    // check to see if any instances already have any of the given URLs or their parents open
+    QList<QUrl> newWindowURLs;
+    for (const QUrl& url : inputUrls) {
         bool urlFound = false;
-        for (auto& interface: dolphinInterfaces) {
-            auto isUrlOpenReply = interface.first->isUrlOpen(url);
+        const QString urlString = url.toString();
+
+        // looping through the windows starting from the active one
+        int i = activeWindowIndex;
+        do {
+            auto &interface = dolphinInterfaces[i];
+
+            auto isUrlOpenReply = openFiles ? interface.first->isUrlOrParentOpen(urlString) : interface.first->isUrlOpen(urlString);
             isUrlOpenReply.waitForFinished();
             if (!isUrlOpenReply.isError() && isUrlOpenReply.value()) {
-                interface.second.append(url);
+                interface.second.append(urlString);
                 urlFound = true;
                 break;
             }
+
+            i = (i + 1) % dolphinInterfaces.size();
         }
+        while (i != activeWindowIndex);
+
         if (!urlFound) {
-            newUrls.append(url);
+            if (GeneralSettings::openExternallyCalledFolderInNewTab()) {
+                dolphinInterfaces[activeWindowIndex].second.append(urlString);
+            } else {
+                newWindowURLs.append(url);
+            }
         }
     }
 
     for (const auto& interface: qAsConst(dolphinInterfaces)) {
-        auto reply = openFiles ? interface.first->openFiles(newUrls, splitView) : interface.first->openDirectories(newUrls, splitView);
+        if (interface.second.isEmpty()) {
+            continue;
+        }
+        auto reply = openFiles ?
+                    interface.first->openFiles(interface.second, splitView) :
+                    interface.first->openDirectories(interface.second, splitView);
         reply.waitForFinished();
         if (!reply.isError()) {
-            interface.first->activateWindow();
+            interface.first->activateWindow(activationToken);
             attached = true;
-            break;
         }
     }
+    if (attached && !newWindowURLs.isEmpty()) {
+        if (openFiles) {
+            openNewWindow(newWindowURLs, nullptr, Dolphin::OpenNewWindowFlag::Select);
+        } else {
+            openNewWindow(newWindowURLs);
+        }
+    }
+
     return attached;
 }
 
