@@ -42,21 +42,11 @@ public:
     QHash<QByteArray, QVariant> roleValues(const Baloo::File& file,
                                            const QSet<QByteArray>& roles) const;
 
-    QByteArray roleForProperty(const QString& property) const;
-
 protected:
     KBalooRolesProvider();
 
-private:
-    /**
-     * @return User visible string for the given tag-values.
-     *         The tag-values are sorted in alphabetical order.
-     */
-    QString tagsFromValues(const QStringList& values) const;
-
 private:
     QSet<QByteArray> m_roles;
-    QHash<QString, QByteArray> m_roleForProperty;
 
     friend struct KBalooRolesProviderSingleton;
 };
