@@ -13,10 +13,10 @@
 #include "dolphinquery.h"
 
 #include <KLocalizedString>
-#include <KNS3/KMoreToolsMenuFactory>
+#include <KMoreToolsMenuFactory>
 #include <KSeparator>
-#include <config-baloo.h>
-#ifdef HAVE_BALOO
+#include "config-dolphin.h"
+#if HAVE_BALOO
 #include <Baloo/Query>
 #include <Baloo/IndexerConfig>
 #endif
@@ -440,7 +440,7 @@ void DolphinSearchBox::init()
     m_optionsScrollArea->setWidgetResizable(true);
 
     m_topLayout = new QVBoxLayout(this);
-    m_topLayout->setContentsMargins(0, 0, 0, 0);
+    m_topLayout->setContentsMargins(0, Dolphin::LAYOUT_SPACING_SMALL, 0, 0);
     m_topLayout->setSpacing(Dolphin::LAYOUT_SPACING_SMALL);
     m_topLayout->addLayout(searchInputLayout);
     m_topLayout->addWidget(m_optionsScrollArea);
@@ -464,7 +464,7 @@ QString DolphinSearchBox::queryTitle(const QString& text) const
 
 QUrl DolphinSearchBox::balooUrlForSearching() const
 {
-#ifdef HAVE_BALOO
+#if HAVE_BALOO
     const QString text = m_searchInput->text();
 
     Baloo::Query query;
@@ -534,7 +534,7 @@ void DolphinSearchBox::updateFacetsVisible()
 
 bool DolphinSearchBox::isIndexingEnabled() const
 {
-#ifdef HAVE_BALOO
+#if HAVE_BALOO
     const Baloo::IndexerConfig searchInfo;
     return searchInfo.fileIndexingEnabled() && !searchPath().isEmpty() && searchInfo.shouldBeIndexed(searchPath().toLocalFile());
 #else
